@@ -13,16 +13,16 @@ Lim - Framework for RESTful JSON/XML, JSON-RPC, XML-RPC and SOAP
 
 =head1 VERSION
 
-Version 0.20_07
+Version 0.14
 
 =cut
 
-our $VERSION = '0.20_07';
+our $VERSION = '0.14';
 our $CONFIG = {
     log => {
-        obj_debug => 0,
-        rpc_debug => 0,
-        debug => 0,
+        obj_debug => 1,
+        rpc_debug => 1,
+        debug => 1,
         info => 1,
         warn => 1,
         err => 1
@@ -32,7 +32,6 @@ our $CONFIG = {
         srv_listen => 10,
         timeout => 30,
         call_timeout => 300,
-        skip_dns => 0,
         transport => {
             http => {
                 host => undef,
@@ -49,9 +48,6 @@ our $CONFIG = {
             verify => 1,
             verify_require_client_cert => 1,
             ca_path => '/etc/lim/ssl/certs'
-        },
-        json => {
-            pretty => 0
         }
     },
     agent => {
@@ -64,16 +60,17 @@ our $CONFIG = {
         config_file => defined $ENV{HOME} ? $ENV{HOME}.($ENV{HOME} =~ /\/$/o ? '' : '/').'.limrc' : '',
         editor => $ENV{EDITOR},
         host => 'localhost',
-        port => 5353,
-        transport => 'http',
-        protocol => 'rest'
-    },
-    plugin => {
-        load_all => 1,
-        load => {}
+        port => 5353
     }
 };
 
+sub OBJ_DEBUG { 1 }
+sub RPC_DEBUG { 1 }
+sub DEBUG { 1 }
+sub INFO { 1 }
+sub WARN { 1 }
+sub ERR { 1 }
+
 =head1 SYNOPSIS
 
 =over 4
@@ -107,69 +104,7 @@ use their CLI part if available.
 
 =over 4
 
-=item Lim::OBJ_DEBUG
-
-Semi constant sub that controls if object debugging information should sent to
-the log.
-
-=cut
-
-sub OBJ_DEBUG { 1 }
-
-=item Lim::RPC_DEBUG
-
-Semi constant sub that controls if RPC debugging information should sent to the
-log.
-
-=cut
-
-sub RPC_DEBUG { 1 }
-
-=item Lim::DEBUG
-
-Semi constant sub that controls if debugging information should sent to the log.
-
-Common usage:
-Lim::DEBUG and $self->{logger}->debug(...);
-
-=cut
-
-sub DEBUG { 1 }
-
-=item Lim::INFO
-
-Semi constant sub that controls if informational logs should sent to the log.
-
-Common usage:
-Lim::INFO and $self->{logger}->info(...);
-
-=cut
-
-sub INFO { 1 }
-
-=item Lim::WARN
-
-Semi constant sub that controls if warnings should sent to the log.
-
-Common usage:
-Lim::WARN and $self->{logger}->warn(...);
-
-=cut
-
-sub WARN { 1 }
-
-=item Lim::ERR
-
-Semi constant sub that controls if errors should sent to the log.
-
-Common usage:
-Lim::ERR and $self->{logger}->error(...);
-
-=cut
-
-sub ERR { 1 }
-
-=item Lim::Config ->{}
+=item Lim::Config->{}
 
 Return a hash reference to the configuration.
 
@@ -200,12 +135,7 @@ sub MergeConfig {
                         next;
                     }
                 }
-                if (ref($to->{$key}) eq 'ARRAY') {
-                    push(@{$to->{$key}}, @{$from->{$key}});
-                }
-                else {
-                    $to->{$key} = $from->{$key};
-                }
+                $to->{$key} = $from->{$key};
             }
         }
     }
@@ -221,10 +151,10 @@ configuration.
 
 sub LoadConfig {
     my ($filename) = @_;
-
+    
     if (defined $filename and -r $filename) {
         my $yaml;
-
+        
         Lim::DEBUG and Log::Log4perl->get_logger->debug('Loading config ', $filename);
         eval {
             $yaml = YAML::Any::LoadFile($filename);
@@ -247,19 +177,19 @@ configuration.
 
 sub LoadConfigDirectory {
     my ($directory) = @_;
-
-    if (defined $directory and -r $directory and -x $directory and -d $directory) {
+    
+    if (defined $directory and -d $directory) {
         unless(opendir(CONFIGS, $directory)) {
             confess __PACKAGE__, ': Unable to read configurations in directory ', $directory, ': ', $!, "\n";
         }
 
         foreach my $entry (sort readdir(CONFIGS)) {
             my $yaml;
-
+            
             unless(-r $directory.'/'.$entry and $entry =~ /\.yaml$/o) {
                 next;
             }
-
+            
             Lim::DEBUG and Log::Log4perl->get_logger->debug('Loading config ', $entry, ' from directory ', $directory);
             eval {
                 $yaml = YAML::Any::LoadFile($directory.'/'.$entry);
@@ -288,14 +218,14 @@ sub ParseOptions {
         unless ($name and defined $value) {
             confess __PACKAGE__, ': Invalid or unknown option: ', $option, "\n";
         }
-
+        
         my @parts = split(/\./o, $name);
         my $ref = $CONFIG;
         while (defined(my $part = shift(@parts))) {
             unless (scalar @parts) {
                 if ($part =~ /^(.+)\[\]$/o) {
                     $part = $1;
-
+                    
                     if (exists $ref->{$part}) {
                         if (ref($ref->{$part}) eq 'ARRAY') {
                             push(@{$ref->{$part}}, $value);
@@ -313,7 +243,7 @@ sub ParseOptions {
                 }
                 last;
             }
-
+            
             unless (exists $ref->{$part}) {
                 $ref->{$part} = {};
             }
