@@ -86,40 +86,10 @@ reference to itself even on error.
 
 sub Load {
     my ($self) = @_;
-    my @modules;
-
-    if (Lim::Config->{plugin}->{load_all}) {
-        @modules = findsubmod Lim::Plugin;
-    }
-    else {
-        foreach (findsubmod Lim::Plugin) {
-            my $name = $_;
-            $name =~ s/.*:://o;
-            if (exists Lim::Config->{plugin}->{load}->{$_}
-                or exists Lim::Config->{plugin}->{load}->{$name})
-            {
-                push(@modules, $_);
-            }
-        }
-    }
-
-    foreach my $module (@modules) {
-        if (exists Lim::Config->{plugin} and exists Lim::Config->{plugin}->{load}) {
-            if (exists Lim::Config->{plugin}->{load}->{$module} and !Lim::Config->{plugin}->{load}->{$module}) {
-                Lim::WARN and $self->{logger}->warn('Skipping ', $module, ' configured not to load.');
-                next;
-            }
-            
-            my $name = $module;
-            $name =~ s/.*:://o;
-            if (exists Lim::Config->{plugin}->{load}->{$name} and !Lim::Config->{plugin}->{load}->{$name}) {
-                Lim::WARN and $self->{logger}->warn('Skipping ', $module, ' configured not to load.');
-                next;
-            }
-        }
-            
+    
+    foreach my $module (findsubmod Lim::Plugin) {
         if (exists $self->{plugin}->{$module}) {
-            Lim::WARN and $self->{logger}->warn('Plugin ', $module, ' already loaded');
+            $self->{logger}->warn('Plugin ', $module, ' already loaded');
             next;
         }
 
@@ -134,12 +104,12 @@ sub Load {
         eval {
             eval "require $module;";
             die $@ if $@;
-            $name = $module->Name;
+            $name = $module->Module;
             $description = $module->Description;
         };
         
         if ($@) {
-            Lim::WARN and $self->{logger}->warn('Unable to load plugin ', $module, ': ', $@);
+            $self->{logger}->warn('Unable to load plugin ', $module, ': ', $@);
             $self->{plugin}->{$module} = {
                 name => $name,
                 description => $description,
@@ -159,26 +129,13 @@ sub Load {
             loaded => 1
         };
     }
-    
-    if (exists Lim::Config->{plugin} and exists Lim::Config->{plugin}->{load}) {
-        foreach my $module (keys %{Lim::Config->{plugin}->{load}}) {
-            unless (Lim::Config->{plugin}->{load}->{$module}) {
-                next;
-            }
-            
-            unless (exists $self->{plugin}->{$module} or exists $self->{plugin}->{'Lim::Plugin::'.$module}) {
-                Lim::ERR and $self->{logger}->error('Required module ', $module, ' not found');
-                # TODO Should we die here?
-            }
-        }
-    }
-    
+
     $self;
 }
 
 =item @modules = $instance->LoadedModules
 
-Returns a list of loaded plugin's module name (eg Lim::Plugin::Example).
+Returns a list of loaded modules module name (eg Lim::Plugin::Example).
 
 =cut
 
@@ -197,15 +154,15 @@ sub LoadedModules {
 
 =item @modules = $instance->Loaded
 
-Returns a list of hash references of loaded plugins.
+Returns a list of hash references of loaded modules.
 
 =over 4
 
 {
-    name => Short name (eg Example),
+    name => Module short name (eg Example),
     module => Module name (Lim::Plugin::Example),
-    version => Version (Lim::Plugin::Example->VERSION),
-    loaded => True or false if the plugin is loaded (True)
+    version => Module version (Lim::Plugin::Example->VERSION),
+    loaded => True or false if module is loaded (True)
 }
 
 =back
