@@ -5,18 +5,12 @@ use Carp;
 
 use Log::Log4perl ();
 use Scalar::Util qw(blessed weaken);
-use URI::Split ();
 
 use Lim ();
 use Lim::Error ();
 use Lim::Util ();
 use Lim::RPC ();
-use Lim::RPC::Protocols ();
-use Lim::RPC::Transport::Clients ();
-
-use HTTP::Request ();
-use HTTP::Response ();
-use HTTP::Status ();
+use Lim::RPC::Client ();
 
 =encoding utf8
 
@@ -28,14 +22,6 @@ use HTTP::Status ();
 
 See L<Lim> for version.
 
-=over 4
-
-=item OK
-
-=item ERROR
-
-=back
-
 =cut
 
 our $VERSION = $Lim::VERSION;
@@ -49,7 +35,7 @@ sub ERROR (){ -1 }
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
@@ -64,18 +50,18 @@ sub new {
     my $real_self = $self;
     weaken($self);
 
-    $self->{plugin} = shift;
+    $self->{module} = shift;
     $self->{call} = shift;
     $self->{call_def} = shift;
     $self->{component} = shift;
     my ($data, $cb, $args, $method, $uri);
-
+    
     $args = {};
     if (scalar @_ == 1) {
         unless (ref($_[0]) eq 'CODE') {
             confess __PACKAGE__, ': Given one argument but its not a CODE callback';
         }
-
+        
         $cb = $_[0];
     }
     elsif (scalar @_ == 2) {
@@ -95,24 +81,15 @@ sub new {
         unless (ref($_[1]) eq 'CODE') {
             confess __PACKAGE__, ': Given three argument but second its not a CODE callback';
         }
-
+        
         $data = $_[0];
         $cb = $_[1];
         $args = $_[2];
     }
-    elsif (scalar @_ > 3) {
-        unless (ref($_[1]) eq 'CODE') {
-            confess __PACKAGE__, ': Given three argument but second its not a CODE callback';
-        }
-
-        $data = shift;
-        $cb = shift;
-        $args = { @_ };
-    }
     else {
         confess __PACKAGE__, ': Too many arguments';
     }
-
+    
     unless (ref($args) eq 'HASH') {
         confess __PACKAGE__, ': Given an arguments argument but its not an hash';
     }
@@ -130,180 +107,93 @@ sub new {
         confess __PACKAGE__, ': No cb specified';
     }
 
-    if (defined $args->{uri}) {
-        my ($scheme, $auth, $path) = URI::Split::uri_split(delete $args->{uri});
-        my ($transport, $protocol);
-
-        if ($scheme =~ /^([a-z0-9_\-\.]+)\+([a-z0-9_\-\.\+]+)/o) {
-            ($transport, $protocol) = ($1, $2);
-        }
-        else {
-            confess __PACKAGE__, ': Invalid schema in uri '.$uri;
-        }
-
-        $uri = URI->new('', 'http');
-        $uri->path($path);
-        $uri->authority($auth);
-        my ($user, $pass) = split(/:/o, $uri->userinfo);
-
-        $self->{host} = $uri->host;
-        $self->{port} = $uri->_port;
-        $self->{user} = $user;
-        $self->{pass} = $pass;
-        $self->{path} = $uri->path;
-        $self->{transport} = $transport;
-        $self->{protocol} = $protocol;
+    if (defined $args->{host}) {
+        $self->{host} = $args->{host};
     }
     else {
-        foreach (qw(host port user pass path transport protocol)) {
-            $self->{$_} = defined $args->{$_} ? delete $args->{$_} : Lim::Config->{cli}->{$_};
-        }
+        $self->{host} = Lim::Config->{host};
+    }
+    if (defined $args->{port}) {
+        $self->{port} = $args->{port};
+    }
+    else {
+        $self->{port} = Lim::Config->{port};
     }
     $self->{cb} = $cb;
-
-    foreach (qw(host transport protocol)) {
-        unless (defined $self->{$_}) {
-            confess __PACKAGE__, ': No '.$_.' specified';
-        }
+    
+    unless (defined $self->{host}) {
+        confess __PACKAGE__, ': No host specified';
     }
-
-    unless (defined ($self->{protocol_obj} = Lim::RPC::Protocols->instance->protocol($self->{protocol}))) {
-        confess __PACKAGE__, ': Unsupported protocol '.$self->{protocol};
+    unless (defined $self->{port}) {
+        confess __PACKAGE__, ': No port specified';
     }
-    unless (defined ($self->{transport_obj} = Lim::RPC::Transport::Clients->instance->transport($self->{transport}))) {
-        confess __PACKAGE__, ': Unsupported transport '.$self->{transport};
-    }
-
+    
     if (defined $data and ref($data) ne 'HASH') {
         confess __PACKAGE__, ': Data is not a hash';
     }
     if (exists $self->{call_def}->{in}) {
-        undef $@;
-        eval {
-            Lim::RPC::V(defined $data ? $data : {}, $self->{call_def}->{in});
-        };
-        if ($@) {
-            undef $@;
-            eval {
-                eval 'use Data::Dumper;';
-                confess __PACKAGE__, ': Unable to verify data ', "\n",
-                    Dumper(defined $data ? $data : {}), "\n",
-                    Dumper($self->{call_def}->{in}), "\n",
-                    $@;
-            };
-            if ($@) {
-                confess __PACKAGE__, ': Unable to verify data';
-            }
-        }
+        Lim::RPC::V(defined $data ? $data : {}, $self->{call_def}->{in});
     }
     elsif (defined $data and %$data) {
         confess __PACKAGE__, ': Data given without in parameter definition';
     }
+    
+    ($method, $uri) = Lim::Util::URIize($self->{call});
+    
+    $uri = '/'.lc($self->{module}).$uri;
 
-    my $request;
-    eval {
-        $request = $self->{protocol_obj}->request(
-            (map { $_ => $self->{$_} } qw(plugin call path)),
-            data => $data
-        );
-    };
-    if ($@ or !defined $request) {
-        confess __PACKAGE__, ': Protocol request creation failed: '.(($@) ? $@ : 'Unknown');
-    }
-
-    $self->{component}->_addCall($self);
-    $self->{transport_obj}->request(
-        %$args,
-        (map { $_ => $self->{$_} } qw(plugin call host port user pass)),
-        request => $request,
+    $self->{component}->_addCall($real_self);
+    $self->{client} = Lim::RPC::Client->new(
+        host => $self->{host},
+        port => $self->{port},
+        method => $method,
+        uri => $uri,
+        data => $data,
         cb => sub {
-            my (undef, $response) = @_;
-            my $data;
+            my (undef, $data) = @_;
 
-            unless (defined $self) {
-                return;
-            }
-
-            unless (blessed $response) {
-                $self->{error} = Lim::Error->new(
-                    message => 'Transport returned invalid response',
-                    module => $self
-                );
-                $self->{status} = ERROR;
-            }
-            elsif ($response->isa('Lim::Error')) {
-                $self->{error} = $response;
-                $self->{status} = ERROR;
-            }
-            elsif ($response->isa('HTTP::Response')) {
-                eval {
-                    $data = $self->{protocol_obj}->response($response);
-                };
-
-                if ($@) {
-                    $self->{error} = Lim::Error->new(
-                        message => 'Protocol response failure: '.$@,
-                        module => $self
-                    );
-                    $self->{status} = ERROR;
-                    $data = undef;
-                }
-                elsif (blessed $data and $data->isa('Lim::Error')) {
-                    $self->{error} = $data;
-                    $self->{status} = ERROR;
-                    $data = undef;
-                }
-                elsif (ref($data) ne 'HASH') {
-                    $self->{error} = Lim::Error->new(
-                        message => 'Protocol returned invalid data from response',
-                        module => $self
-                    );
-                    $self->{status} = ERROR;
-                    $data = undef;
-                }
-                else {
-                    if (exists $self->{call_def}->{out}) {
-                        eval {
-                            Lim::RPC::V($data, $self->{call_def}->{out});
-                        };
-                        if ($@) {
-                            $self->{error} = Lim::Error->new(
-                                message => $@,
-                                module => $self
-                            );
-                            $self->{status} = ERROR;
-                            $data = undef;
-                        }
-                        else {
-                            $self->{status} = OK;
-                        }
-                    }
-                    elsif (%$data) {
+            if ($self->{client}->status == Lim::RPC::Client::OK) {
+                $self->{status} = OK;
+                if (exists $self->{call_def}->{out}) {
+                    eval {
+                        Lim::RPC::V($data, $self->{call_def}->{out});
+                    };
+                    if ($@) {
                         $self->{error} = Lim::Error->new(
-                            message => 'Invalid data return, does not match definition',
+                            message => $@,
                             module => $self
                         );
                         $self->{status} = ERROR;
-                        $data = undef;
-                    }
-                    else {
-                        $self->{status} = OK;
                     }
                 }
+                elsif (%$data) {
+                    $self->{error} = Lim::Error->new(
+                        message => 'Invalid data return, does not match definition',
+                        module => $self
+                    );
+                    $self->{status} = ERROR;
+                }
             }
             else {
-                $self->{error} = Lim::Error->new(
-                    message => 'Transport returned invalid response',
-                    module => $self
-                );
                 $self->{status} = ERROR;
+                if (blessed $data and $data->isa('Lim::Error')) {
+                    $self->{error} = $data;
+                }
+                else {
+                    $self->{error} = Lim::Error->new(
+                        message => $data,
+                        module => $self
+                    );
+                }
+                undef($data);
             }
-
+            
+            delete $self->{client};
             $self->{cb}->($self, $data);
             $self->{component}->_deleteCall($self);
         }
     );
-
+    
     Lim::OBJ_DEBUG and $self->{logger}->debug('new ', __PACKAGE__, ' ', $self);
     $real_self;
 }
@@ -313,7 +203,7 @@ sub DESTROY {
     Lim::OBJ_DEBUG and $self->{logger}->debug('destroy ', __PACKAGE__, ' ', $self);
 }
 
-=head2 Successful
+=head2 function1
 
 =cut
 
@@ -321,7 +211,7 @@ sub Successful {
     $_[0]->{status} == OK;
 }
 
-=head2 Error
+=head2 function1
 
 =cut
 
@@ -329,7 +219,7 @@ sub Error {
     $_[0]->{error};
 }
 
-=head2 ResetTimeout
+=head2 function1
 
 =cut
 
