@@ -28,7 +28,7 @@ our $VERSION = $Lim::VERSION;
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
@@ -37,18 +37,15 @@ sub new {
     my $class = ref($this) || $this;
     my %args = ( @_ );
     my $self = {
-        logger => Log::Log4perl->get_logger,
-        server => undef
+        logger => Log::Log4perl->get_logger
     };
     bless $self, $class;
 
-    if (exists $args{server}) {
-        unless (blessed($args{server}) and $args{server}->isa('Lim::RPC::Server')) {
-            confess __PACKAGE__, ': No server specified or invalid';
-        }
-        $self->{__server} = $args{server};
-        weaken($self->{__server});
+    unless (blessed($args{server}) and $args{server}->isa('Lim::RPC::Server')) {
+        confess __PACKAGE__, ': No server specified or invalid';
     }
+    $self->{__server} = $args{server};
+    weaken($self->{__server});
 
     $self->Init(@_);
 
@@ -64,21 +61,21 @@ sub DESTROY {
     delete $self->{__server};
 }
 
-=head2 Init
+=head2 function1
 
 =cut
 
 sub Init {
 }
 
-=head2 Destroy
+=head2 function1
 
 =cut
 
 sub Destroy {
 }
 
-=head2 name
+=head2 function1
 
 =cut
 
@@ -86,7 +83,7 @@ sub name {
     confess 'function name not overloaded';
 }
 
-=head2 serve
+=head2 function1
 
 =cut
 
@@ -94,7 +91,7 @@ sub serve {
     confess 'function serve not overloaded';
 }
 
-=head2 handle
+=head2 function1
 
 =cut
 
@@ -102,7 +99,7 @@ sub handle {
     confess 'function handle not overloaded';
 }
 
-=head2 timeout
+=head2 function1
 
 =cut
 
@@ -110,7 +107,7 @@ sub timeout {
     confess 'function timeout not overloaded';
 }
 
-=head2 server
+=head2 function1
 
 =cut
 
@@ -118,7 +115,7 @@ sub server {
     $_[0]->{__server};
 }
 
-=head2 precall
+=head2 function1
 
 =cut
 
@@ -128,22 +125,6 @@ sub precall {
     return @_;
 }
 
-=head2 request
-
-=cut
-
-sub request {
-    confess 'function request not overloaded';
-}
-
-=head2 response
-
-=cut
-
-sub response {
-    confess 'function response not overloaded';
-}
-
 =head1 AUTHOR
 
 Jerry Lundström, C<< <lundstrom.jerry at gmail.com> >>
