@@ -37,14 +37,14 @@ our $VERSION = $Lim::VERSION;
 
 =head1 SUBROUTINES/METHODS
 
-=head2 Init
+=head2 function1
 
 =cut
 
 sub Init {
 }
 
-=head2 Destroy
+=head2 function1
 
 =cut
 
@@ -55,7 +55,7 @@ sub Destroy {
     delete $self->{wsdl};
 }
 
-=head2 name
+=head2 function1
 
 =cut
 
@@ -63,7 +63,7 @@ sub name {
     'soap';
 }
 
-=head2 serve
+=head2 function1
 
 =cut
 
@@ -213,7 +213,7 @@ sub serve {
     $self;
 }
 
-=head2 __wsdl_gen_complex_types
+=head2 function2
 
 =cut
 
@@ -283,7 +283,7 @@ sub __wsdl_gen_complex_types {
     $wsdl;
 }
 
-=head2 handle
+=head2 function1
 
 =cut
 
@@ -297,7 +297,6 @@ sub handle {
     if ($request->header('SOAPAction') and $request->uri =~ /^\/([a-zA-Z]+)\s*$/o) {
         my ($module) = ($1);
         my $response = HTTP::Response->new;
-        my $http_request = $request;
         $response->request($request);
         $response->protocol($request->protocol);
         
@@ -320,7 +319,6 @@ sub handle {
                 }
                 
                 $request->{__lim_rpc_protocol_soap_cb} = Lim::RPC::Callback->new(
-                    request => $http_request,
                     cb => sub {
                         my ($data) = @_;
                         
@@ -376,7 +374,7 @@ sub handle {
                 $soap->handle;
             };
             if ($@) {
-                Lim::WARN and $self->{logger}->warn('SOAP action failed: ', $@);
+                $self->{logger}->warn('SOAP action failed: ', $@);
                 $response->code(HTTP_INTERNAL_SERVER_ERROR);
             }
             else {
@@ -426,7 +424,7 @@ sub handle {
     return;
 }
 
-=head2 __soap_result
+=head2 function1
 
 =cut
 
@@ -472,7 +470,7 @@ sub __soap_result {
     }
 }
 
-=head2 precall
+=head2 function1
 
 =cut
 
