@@ -37,7 +37,7 @@ our $VERSION = $Lim::VERSION;
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
@@ -49,8 +49,7 @@ sub new {
         logger => Log::Log4perl->get_logger,
         protocol => {},
         transports => [],
-        module => {},
-        transport_modules => {}
+        module => {}
     };
     bless $self, $class;
 
@@ -59,22 +58,6 @@ sub new {
     }
 
     foreach my $uri (ref($args{uri}) eq 'ARRAY' ? @{$args{uri}} : $args{uri}) {
-        my $modules;
-        my $transport_config = {};
-
-        if (ref($uri) eq 'HASH') {
-            if (ref($uri->{plugin}) eq 'ARRAY') {
-                $modules = { map { $_ => 1 } @{$uri->{plugin}} };
-            }
-            unless (defined $uri->{uri}) {
-                next;
-            }
-            if (ref($uri->{transport}) eq 'HASH') {
-                $transport_config = $uri->{transport};
-            }
-            $uri = $uri->{uri};
-        }
-
         my ($scheme, $auth, $path, $query, $frag) = URI::Split::uri_split($uri);
 
         if ($scheme =~ /^([a-z0-9_\-\.]+)(?:\+([a-z0-9_\-\.\+]+))*/o) {
@@ -83,7 +66,7 @@ sub new {
             $uri = URI->new('', 'http');
             $uri->query($query);
             $uri->host_port($auth);
-
+            
             foreach my $protocol_name (split(/\+/o, $protocols)) {
                 unless (exists $self->{protocol}->{$protocol_name}) {
                     my $protocol;
@@ -91,7 +74,7 @@ sub new {
                     unless (defined ($protocol = Lim::RPC::Protocols->instance->protocol($protocol_name, server => $self))) {
                         confess __PACKAGE__, ': Protocol ', $protocol_name, ' does not exists';
                     }
-
+                    
                     $self->{protocol}->{$protocol_name} = $protocol;
                     push(@protocols, $protocol);
                 }
@@ -99,19 +82,13 @@ sub new {
                     push(@protocols, $self->{protocol}->{$protocol_name});
                 }
             }
-
-            unless (defined ($transport = Lim::RPC::Transports->instance->transport($transport_name,
-                (ref($transport_config->{$transport_name}) eq 'HASH' ? (%{$transport_config->{$transport_name}}) : ()),
-                server => $self, uri => $uri)))
-            {
+            
+            unless (defined ($transport = Lim::RPC::Transports->instance->transport($transport_name, server => $self, uri => $uri))) {
                 confess __PACKAGE__, ': Transport ', $transport_name, ' does not exists';
             }
-
+            
             $transport->add_protocol(@protocols);
             push(@{$self->{transports}}, $transport);
-            if ($modules) {
-                $self->{transport_modules}->{$transport} = $modules;
-            }
         }
         else {
             confess __PACKAGE__, ': Unable to parse URI schema: ', $uri;
@@ -131,7 +108,7 @@ sub DESTROY {
     delete $self->{protocol};
 }
 
-=head2 serve
+=head2 function2
 
 =cut
 
@@ -144,47 +121,43 @@ sub serve {
         eval {
             $obj = $module->Server;
         };
-        if ($@) {
-            Lim::WARN and $self->{logger}->warn('Can not serve ', $module, ': ', $@);
-            next;
-        }
-        unless (defined $obj) {
-            Lim::DEBUG and $self->{logger}->debug('Can not serve ', $module, ': no object from Module->Server so may only have Client installed');
+        if (!defined $obj or $@) {
+            $self->{logger}->warn('Can not serve ', $module, (defined $@ ? ': '.$@ : ''));
             next;
         }
 
         if ($obj->isa('Lim::Component::Server')) {
-            my $name = lc($module->Name);
-
+            my $name = lc($module->Module);
+            
             if (exists $self->{module}->{$name}) {
-                Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': plugin already served');
+                $self->{logger}->warn('Can not serve ', $name, ': module already served');
                 next;
             }
-
+            
             unless ($module->VERSION) {
-                Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': no VERSION specified in plugin');
+                $self->{logger}->warn('Can not serve ', $name, ': no VERSION specified in module');
                 next;
             }
-
+            
             my $calls = $module->Calls;
             unless ($calls) {
-                Lim::INFO and $self->{logger}->info('Not serving ', $name, ', nothing to serve');
+                $self->{logger}->info('Not serving ', $name, ', nothing to serve');
                 next;
             }
             unless (ref($calls) eq 'HASH') {
-                Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': Calls() return was invalid');
+                $self->{logger}->warn('Can not serve ', $name, ': Calls() return was invalid');
                 next;
             }
             unless (%$calls) {
-                Lim::INFO and $self->{logger}->info('Not serving ', $name, ', nothing to serve');
+                $self->{logger}->info('Not serving ', $name, ', nothing to serve');
                 next;
             }
-
+            
             my $uri_maps = {};
-
+            
             foreach my $call (keys %$calls) {
                 unless ($obj->can($call)) {
-                    Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': Missing specified call ', $call, ' function');
+                    $self->{logger}->warn('Can not serve ', $name, ': Missing specified call ', $call, ' function');
                     undef($calls);
                     last;
                 }
@@ -203,34 +176,34 @@ sub serve {
 
                 if ($create_call) {
                     my $call_def = $calls->{$call};
-
+                    
                     unless (ref($call_def) eq 'HASH') {
-                        Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid definition');
+                        $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid definition');
                         undef($calls);
                         last;
                     }
-
+                    
                     if (exists $call_def->{uri_map}) {
                         unless (ref($call_def->{uri_map}) eq 'ARRAY') {
-                            Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map parameter definition');
+                            $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map parameter definition');
                             undef($calls);
                             last;
                         }
-
+                        
                         my $uri_map = Lim::RPC::URIMaps->new;
-
+                        
                         foreach my $map (@{$call_def->{uri_map}}) {
                             if (defined (my $redirect_call = $uri_map->add($map))) {
                                 if ($redirect_call) {
                                     unless (exists $calls->{$redirect_call}) {
-                                        Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map: redirected to non-existing call ', $redirect_call);
+                                        $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map: redirected to non-existing call ', $redirect_call);
                                         undef($calls);
                                         last;
                                     }
                                 }
                             }
                             else {
-                                Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map: ', $@);
+                                $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid uri_map: ', $@);
                                 undef($calls);
                                 last;
                             }
@@ -238,24 +211,24 @@ sub serve {
                         unless (defined $calls) {
                             last;
                         }
-
+                        
                         $uri_maps->{$call} = $uri_map;
                     }
-
+                    
                     if (exists $call_def->{in}) {
                         unless (ref($call_def->{in}) eq 'HASH') {
-                            Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid in parameter definition');
+                            $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid in parameter definition');
                             undef($calls);
                             last;
                         }
-
+                        
                         my @keys = keys %{$call_def->{in}};
                         unless (scalar @keys) {
-                            Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid in parameter definition');
+                            $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid in parameter definition');
                             undef($calls);
                             last;
                         }
-
+                                                
                         my @values = ($call_def->{in});
                         while (defined $calls and (my $value = shift(@values))) {
                             foreach my $key (keys %$value) {
@@ -270,7 +243,7 @@ sub serve {
                                             push(@values, $value->{$key}->children);
                                             next;
                                         }
-                                        Lim::WARN and $self->{logger}->warn('Unable to create Lim::RPC::Value::Collection: ', $@);
+                                        $self->{logger}->warn('Unable to create Lim::RPC::Value::Collection: ', $@);
                                     }
                                     else {
                                         push(@values, $value->{$key});
@@ -293,29 +266,29 @@ sub serve {
                                     unless ($@) {
                                         next;
                                     }
-                                    Lim::WARN and $self->{logger}->warn('Unable to create Lim::RPC::Value: ', $@);
+                                    $self->{logger}->warn('Unable to create Lim::RPC::Value: ', $@);
                                 }
 
-                                Lim::WARN and $self->{logger}->warn('Can not server ', $name, ': call ', $call, ' has invalid in parameter definition');
+                                $self->{logger}->warn('Can not server ', $name, ': call ', $call, ' has invalid in parameter definition');
                                 undef($calls);
                             }
                         }
-
+                        
                         unless (defined $calls) {
                             last;
                         }
                     }
-
+                    
                     if (exists $call_def->{out}) {
                         unless (ref($call_def->{out}) eq 'HASH') {
-                            Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid out parameter definition');
+                            $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid out parameter definition');
                             undef($calls);
                             last;
                         }
-
+                        
                         my @keys = keys %{$call_def->{out}};
                         unless (scalar @keys) {
-                            Lim::WARN and $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid out parameter definition');
+                            $self->{logger}->warn('Can not serve ', $name, ': call ', $call, ' has invalid out parameter definition');
                             undef($calls);
                             last;
                         }
@@ -334,7 +307,7 @@ sub serve {
                                             push(@values, $value->{$key}->children);
                                             next;
                                         }
-                                        Lim::WARN and $self->{logger}->warn('Unable to create Lim::RPC::Value::Collection: ', $@);
+                                        $self->{logger}->warn('Unable to create Lim::RPC::Value::Collection: ', $@);
                                     }
                                     else {
                                         push(@values, $value->{$key});
@@ -357,19 +330,19 @@ sub serve {
                                     unless ($@) {
                                         next;
                                     }
-                                    Lim::WARN and $self->{logger}->warn('Unable to create Lim::RPC::Value: ', $@);
+                                    $self->{logger}->warn('Unable to create Lim::RPC::Value: ', $@);
                                 }
 
-                                Lim::WARN and $self->{logger}->warn('Can not server ', $name, ': call ', $call, ' has invalid out parameter definition');
+                                $self->{logger}->warn('Can not server ', $name, ': call ', $call, ' has invalid out parameter definition');
                                 undef($calls);
                             }
                         }
-
+                        
                         unless (defined $calls) {
                             last;
                         }
                     }
-
+                    
                     my $logger = $self->{logger};
                     weaken($logger);
 
@@ -385,7 +358,7 @@ sub serve {
                         if ($base->isa('UNIVERSAL') and $base->can($call)) {
                             next;
                         }
-
+                        
                         no strict 'refs';
                         *$protocol_call = sub {
                             unless (defined $protocol and defined $weak_obj and defined $call_def) {
@@ -396,28 +369,28 @@ sub serve {
                                ($self, $cb, $q, @args) = $protocol->precall($call, @_);
                             };
                             if ($@) {
-                                Lim::WARN and defined $logger and $logger->warn($weak_obj, '->', $call, '() precall failed: ', $@);
+                                defined $logger and $logger->warn($weak_obj, '->', $call, '() precall failed: ', $@);
                                 $weak_obj->Error($cb);
                                 return;
                             }
-
+                            
                             Lim::RPC_DEBUG and defined $logger and $logger->debug('Call to ', $weak_obj, ' ', $call);
 
                             if (!defined $q) {
                                 $q = {};
                             }
                             if (ref($q) ne 'HASH') {
-                                Lim::WARN and defined $logger and $logger->warn($weak_obj, '->', $call, '() called without data as hash');
+                                defined $logger and $logger->warn($weak_obj, '->', $call, '() called without data as hash');
                                 $weak_obj->Error($cb);
                                 return;
                             }
-
+                            
                             if (exists $call_def->{in}) {
                                 eval {
                                     Lim::RPC::V($q, $call_def->{in});
                                 };
                                 if ($@) {
-                                    Lim::WARN and defined $logger and $logger->warn($weak_obj, '->', $call, '() data validation failed: ', $@);
+                                    defined $logger and $logger->warn($weak_obj, '->', $call, '() data validation failed: ', $@);
                                     Lim::DEBUG and defined $logger and eval {
                                         use Data::Dumper;
                                         $logger->debug(Dumper($q));
@@ -428,17 +401,17 @@ sub serve {
                                 }
                             }
                             elsif (%$q) {
-                                Lim::WARN and defined $logger and $logger->warn($weak_obj, '->', $call, '() have data but no definition');
+                                defined $logger and $logger->warn($weak_obj, '->', $call, '() have data but no definition');
                                 $weak_obj->Error($cb);
                                 return;
                             }
                             $cb->set_call_def($call_def);
-
+                            
                             eval {
                                 $weak_obj->$call($cb, $q, @args);
                             };
                             if ($@) {
-                                Lim::WARN and defined $logger and $logger->warn($weak_obj, '->', $call, '() failed: ', $@);
+                                defined $logger and $logger->warn($weak_obj, '->', $call, '() failed: ', $@);
                                 $weak_obj->Error($cb);
                             }
                             return;
@@ -451,7 +424,7 @@ sub serve {
             }
 
             Lim::DEBUG and $self->{logger}->debug('serving ', $name);
-
+            
             $self->{module}->{$name} = {
                 name => $name,
                 module => $module,
@@ -461,39 +434,29 @@ sub serve {
             };
 
             foreach my $protocol (values %{$self->{protocol}}) {
-                Lim::DEBUG and $self->{logger}->debug('serving ', $name, ' to protocol ', $protocol->name);
                 $protocol->serve($module, $name);
             }
-            foreach my $transport (@{$self->{transports}}) {
-                if (exists $self->{transport_modules}->{$transport}
-                    and !exists $self->{transport_modules}->{$transport}->{$module->Name})
-                {
-                    next;
-                }
-                Lim::DEBUG and $self->{logger}->debug('serving ', $name, ' to transport ', $transport->name, ' at ', $transport->uri);
-                $transport->serve($module, $name);
-            }
         }
     }
-
+    
     $self;
 }
 
-=head2 have_module
+=head2 function2
 
 =cut
 
 sub have_module {
     my ($self, $module) = @_;
-
+    
     unless (exists $self->{module}->{$module}) {
         return;
     }
-
+    
     return 1;
 }
 
-=head2 have_module_call
+=head2 function2
 
 =cut
 
@@ -507,11 +470,11 @@ sub have_module_call {
     unless (exists $self->{module}->{$module}->{calls}->{$call}) {
         return;
     }
-
+    
     return 1;
 }
 
-=head2 module_obj
+=head2 function2
 
 =cut
 
@@ -525,7 +488,7 @@ sub module_obj {
     return $self->{module}->{$module}->{obj};
 }
 
-=head2 module_class
+=head2 function2
 
 =cut
 
@@ -539,13 +502,13 @@ sub module_class {
     return $self->{module}->{$module}->{module};
 }
 
-=head2 module_obj_by_protocol
+=head2 function2
 
 =cut
 
 sub module_obj_by_protocol {
     my ($self, $module, $protocol) = @_;
-
+    
     unless (exists $self->{module}->{$module}) {
         return;
     }
@@ -553,11 +516,11 @@ sub module_obj_by_protocol {
     unless (exists $self->{protocol}->{$protocol}) {
         return;
     }
-
+    
     bless {}, 'Lim::RPC::ProtocolCall::'.$protocol.'::'.$self->{module}->{$module}->{module}.'::Server';
 }
 
-=head2 process_module_call_uri_map
+=head2 function2
 
 =cut
 
@@ -567,7 +530,7 @@ sub process_module_call_uri_map {
     unless (exists $self->{module}->{$module}) {
         return;
     }
-
+    
     unless (ref($data) eq 'HASH') {
         return;
     }
@@ -579,43 +542,6 @@ sub process_module_call_uri_map {
     return $self->{module}->{$module}->{uri_maps}->{$call}->process($uri, $data);
 }
 
-=head2 transports
-
-=cut
-
-sub transports {
-    @{$_[0]->{transports}};
-}
-
-=head2 close
-
-=cut
-
-sub close {
-    my ($self, $cb) = @_;
-
-    unless (ref($cb) eq 'CODE') {
-        confess '$cb is not CODE';
-    }
-
-    my $cv = AnyEvent->condvar;
-    $cv->begin(sub {
-        $cb->();
-        $cv = undef;
-    });
-
-    foreach my $transport (@{$self->{transports}}) {
-        $cv->begin;
-        Lim::DEBUG and $self->{logger}->debug('Closing transport ', $transport->name);
-        $transport->close(sub {
-            $cv->end;
-        });
-    }
-    $cv->end;
-
-    $self;
-}
-
 =head1 AUTHOR
 
 Jerry Lundström, C<< <lundstrom.jerry at gmail.com> >>
