@@ -28,7 +28,7 @@ our $VERSION = $Lim::VERSION;
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
@@ -63,21 +63,21 @@ sub DESTROY {
     delete $self->{__server};
 }
 
-=head2 Init
+=head2 function1
 
 =cut
 
 sub Init {
 }
 
-=head2 Destroy
+=head2 function1
 
 =cut
 
 sub Destroy {
 }
 
-=head2 name
+=head2 function1
 
 =cut
 
@@ -85,7 +85,7 @@ sub name {
     confess 'function name not overloaded';
 }
 
-=head2 uri
+=head2 function1
 
 =cut
 
@@ -93,7 +93,7 @@ sub uri {
     confess 'function uri not overloaded';
 }
 
-=head2 add_protocol
+=head2 function1
 
 =cut
 
@@ -110,7 +110,7 @@ sub add_protocol {
     $self;
 }
 
-=head2 protocols
+=head2 function1
 
 =cut
 
@@ -118,7 +118,7 @@ sub protocols {
     @{$_[0]->{__protocols}};
 }
 
-=head2 server
+=head2 function1
 
 =cut
 
@@ -126,46 +126,6 @@ sub server {
     $_[0]->{__server};
 }
 
-=head2 host
-
-=cut
-
-sub host {
-    confess 'function host not overloaded';
-}
-
-=head2 port
-
-=cut
-
-sub port {
-    confess 'function port not overloaded';
-}
-
-=head2 serve
-
-=cut
-
-sub serve {
-    confess 'function serve not overloaded';
-}
-
-=head2 close
-
-=cut
-
-sub close {
-    my ($self, $cb) = @_;
-
-    unless (ref($cb) eq 'CODE') {
-        confess '$cb is not CODE';
-    }
-
-    $cb->();
-
-    $self;
-}
-
 =head1 AUTHOR
 
 Jerry Lundström, C<< <lundstrom.jerry at gmail.com> >>
