@@ -84,11 +84,8 @@ sub load {
     my ($self) = @_;
     
     foreach my $module (findsubmod Lim::RPC::Transport) {
-        if ($module =~ /::Clients?$/o) {
-            next;
-        }
         if (exists $self->{transport}->{$module}) {
-            Lim::WARN and $self->{logger}->warn('Transport ', $module, ' already loaded');
+            $self->{logger}->warn('Transport ', $module, ' already loaded');
             next;
         }
 
@@ -107,7 +104,7 @@ sub load {
         };
         
         if ($@) {
-            Lim::WARN and $self->{logger}->warn('Unable to load transport ', $module, ': ', $@);
+            $self->{logger}->warn('Unable to load transport ', $module, ': ', $@);
             $self->{transport}->{$module} = {
                 name => $name,
                 module => $module,
@@ -118,7 +115,7 @@ sub load {
         }
         
         unless ($name =~ /^[a-z0-9_\-\.]+$/o) {
-            Lim::WARN and $self->{logger}->warn('Unable to load transport ', $module, ': Illegal characters in transport name');
+            $self->{logger}->warn('Unable to load transport ', $module, ': Illegal characters in transport name');
             $self->{transport}->{$module} = {
                 module => $module,
                 loaded => 0,
@@ -128,11 +125,10 @@ sub load {
         }
 
         if (exists $self->{transport_name}->{$name}) {
-            Lim::WARN and $self->{logger}->warn('Transport name ', $name, ' already loaded by module ', $self->{transport_name}->{$name});
+            $self->{logger}->warn('Transport name ', $name, ' already loaded by module ', $self->{transport_name}->{$name});
             next;
         }
 
-        Lim::DEBUG and $self->{logger}->debug('Loaded ', $module);
         $self->{transport}->{$module} = {
             name => $name,
             module => $module,
@@ -169,7 +165,7 @@ sub transport {
                 $transport = $module->new(@_);
             };
             if ($@) {
-                Lim::WARN and $self->{logger}->warn('Unable to create new instance of transport ', $name, '(', $module, '): ', $@);
+                $self->{logger}->warn('Unable to create new instance of transport ', $name, '(', $module, '): ', $@);
             }
             else {
                 return $transport;
