@@ -29,7 +29,7 @@ our %_MAP_CACHE_CODE;
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
@@ -51,7 +51,7 @@ sub DESTROY {
     Lim::OBJ_DEBUG and $self->{logger}->debug('destroy ', __PACKAGE__, ' ', $self);
 }
 
-=head2 add
+=head2 function1
 
 =cut
 
@@ -72,10 +72,9 @@ sub add {
     else {
         $call = '';
     }
-
-    my $map_key = $map.' '.$call;
-    if (exists $_MAP_CACHE_CODE{$map_key} and defined $_MAP_CACHE_CODE{$map_key}) {
-        push(@{$self->{maps}}, $_MAP_CACHE_CODE{$map_key});
+    
+    if (exists $_MAP_CACHE_CODE{$map} and defined $_MAP_CACHE_CODE{$map}) {
+        push(@{$self->{maps}}, $_MAP_CACHE_CODE{$map});
         return $call;
     }
     
@@ -115,15 +114,13 @@ sub add {
     # Generate the code that checked given URI with generated regexp and adds
     # data gotten by the regexp to the data structure defined by the map
     #
-
-    $code = '';
-
+    
     if ($predata) {
         foreach my $predata_variable (split(/,/o, $predata)) {
             if ($predata_variable =~ /^([^=]+)=(.+)$/o) {
                 my ($variable, $value) = ($1, $2);
 
-                $code .= '$data->{'.join('}->{', split(/\./o, $variable)).'} = \''.$value.'\';';
+                $code .= '$data->{'.join('}->{', split(/\./o, $variable)).'} = \''.$value.'\'';
             }
             else {
                 Lim::DEBUG and $self->{logger}->debug('Predata of map "', $map, '" invalid');
@@ -134,7 +131,7 @@ sub add {
     }
 
     if (scalar @variables) {
-        $code .= 'my (';
+        $code = 'my (';
     
         $n = 1;
         while ($n <= scalar @variables) {
@@ -157,6 +154,9 @@ sub add {
             $code .= '$data->{'.join('}->{', split(/\./o, $variable)).'} = $v'.($n++).';';
         }
     }
+    else {
+        $code = '';
+    }
 
     #
     # Create the subroutine from the generated code
@@ -184,13 +184,13 @@ sub add {
     # Store the generated subroutine and return success
     #
 
-    $_MAP_CACHE_CODE{$map_key} = $code;
-    weaken($_MAP_CACHE_CODE{$map_key});
+    $_MAP_CACHE_CODE{$map} = $code;
+    weaken($_MAP_CACHE_CODE{$map});
     push(@{$self->{maps}}, $code);
     return $call;
 }
 
-=head2 process
+=head2 function1
 
 =cut
 
